@@ -3,7 +3,7 @@ package Params::ValidationCompiler::Compiler;
 use strict;
 use warnings;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use Carp qw( croak );
 use Eval::Closure qw( eval_closure );
@@ -896,14 +896,13 @@ Params::ValidationCompiler::Compiler - Object that implements the check subrouti
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =for Pod::Coverage .*
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Params-ValidationCompiler>
-(or L<bug-params-validationcompiler@rt.cpan.org|mailto:bug-params-validationcompiler@rt.cpan.org>).
+Bugs may be submitted through L<https://github.com/houseabsolute/Params-ValidationCompiler/issues>.
 
 I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
